==> farm_haystack-1.11.1rc1.tar.gz: farm_haystack-1.11.1rc1/haystack/modeling/visual.py <==
FLOWERS = r"""
         
   vVVVv                  vVVVv      
   (___)       vVVVv      (___)       vVVVv
    ~Y~        (___)       ~Y~        (___)
    \|         \~Y~/       \|         \~Y~/
   \\|//       \\|//      \\|//       \\|//
   ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
"""

SAMPLE = r"""
      .--.        _____                       _      
    .'_\/_'.     / ____|                     | |     
    '. /\ .'    | (___   __ _ _ __ ___  _ __ | | ___ 
      "||"       \___ \ / _` | '_ ` _ \| '_ \| |/ _ \ 
       || /\     ____) | (_| | | | | | | |_) | |  __/
    /\ ||//\)   |_____/ \__,_|_| |_| |_| .__/|_|\___|
   (/\\||/                             |_|           
______\||/___________________________________________                     
"""

FENCE = r"""
  _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _ 
_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_
-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-
 | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_
-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-
 |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_|  
,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,

"""

TRACTOR_SMALL = r""" 
              ______
               |o  |   !
   __          |:`_|---'-.
  |__|______.-/ _ \-----.|       
 (o)(o)------'\ _ /     ( )      
 """


TRACTOR_WITH_SILO_LINE = r""" 
                                     ____
                                    /____\
              ______               |      |
               |o  |   !           |      | 
   __          |:`_|---'-.         |      |
  |__|______.-/ _ \-----.|         |______|
 (o)(o)------'\ _ /     ( )        |      |
 """


ROOSTER = r"""
                             _  m
                           ,`.\/'>
                           (`\<_/`
                             `<<
"""

PIG = r"""

        .-~~~~-. |\\_
     @_/        /  oo\_
       |    \   \   _(")
        \   /-| ||'--'
         \_\  \_\\

"""
SMALL_PIG = r"""
     @___,__
     (   ^'_]
     //-\\'
     ^^  ^^
"""
FENCE_SEP = r"""
|---||---|---|---|---|---|---|---|
"""

BUSH_SEP = r"""\\|//       \\|//      \\|//       \\|//     \\|//
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"""

WATERING_CAN = r"""
            ______                                         
 _        ,',----.`.                   
'.`-.  .-' '----. ||                                       
   `.`-'--------| ;;      
     `.|--------|//                                        
       \         /         
       '--------'                                       
"""

WORKER_M = r""" 0  
/|\ 
/'\ """

WORKER_F = r""" 0  
/w\ 
/ \ """

WORKER_X = r""" 0  
/w\ 
/'\ """

==> farm_haystack-1.14.0rc2.tar.gz: farm_haystack-1.14.0rc2/haystack/modeling/visual.py <==
FLOWERS = r"""

   vVVVv                  vVVVv
   (___)       vVVVv      (___)       vVVVv
    ~Y~        (___)       ~Y~        (___)
    \|         \~Y~/       \|         \~Y~/
   \\|//       \\|//      \\|//       \\|//
   ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
"""

SAMPLE = r"""
      .--.        _____                       _
    .'_\/_'.     / ____|                     | |
    '. /\ .'    | (___   __ _ _ __ ___  _ __ | | ___
      "||"       \___ \ / _` | '_ ` _ \| '_ \| |/ _ \
       || /\     ____) | (_| | | | | | | |_) | |  __/
    /\ ||//\)   |_____/ \__,_|_| |_| |_| .__/|_|\___|
   (/\\||/                             |_|
______\||/___________________________________________
"""

FENCE = r"""
  _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _   _
_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_
-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-
 | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_
-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-| |-
 |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_| |_|
,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,

"""

TRACTOR_SMALL = r"""
              ______
               |o  |   !
   __          |:`_|---'-.
  |__|______.-/ _ \-----.|
 (o)(o)------'\ _ /     ( )
 """


TRACTOR_WITH_SILO_LINE = r"""
                                     ____
                                    /____\
              ______               |      |
               |o  |   !           |      |
   __          |:`_|---'-.         |      |
  |__|______.-/ _ \-----.|         |______|
 (o)(o)------'\ _ /     ( )        |      |
 """


ROOSTER = r"""
                             _  m
                           ,`.\/'>
                           (`\<_/`
                             `<<
"""

PIG = r"""

        .-~~~~-. |\\_
     @_/        /  oo\_
       |    \   \   _(")
        \   /-| ||'--'
         \_\  \_\\

"""
SMALL_PIG = r"""
     @___,__
     (   ^'_]
     //-\\'
     ^^  ^^
"""
FENCE_SEP = r"""
|---||---|---|---|---|---|---|---|
"""

BUSH_SEP = r"""\\|//       \\|//      \\|//       \\|//     \\|//
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"""

WATERING_CAN = r"""
            ______
 _        ,',----.`.
'.`-.  .-' '----. ||
   `.`-'--------| ;;
     `.|--------|//
       \         /
       '--------'
"""

WORKER_M = r""" 0    # pylint: disable=trailing-whitespace
/|\
/'\ """

WORKER_F = r""" 0  # pylint: disable=trailing-whitespace
/w\
/ \ """

WORKER_X = r""" 0  # pylint: disable=trailing-whitespace
/w\
/'\ """
